pub fn pull_index_bundle(project_root: &Path) -> Result<BundleManifest, String>Expand description
Download, decrypt and unpack the hosted bundle for this project. Returns the bundle manifest on success.
pub fn pull_index_bundle(project_root: &Path) -> Result<BundleManifest, String>Download, decrypt and unpack the hosted bundle for this project. Returns the bundle manifest on success.