verify

Function verify 

pub fn verify(
    installed: &[&InstalledAddon],
    servers: &[GatewayServer],
) -> Vec<IntegrityFinding>
Re-verify every installed addon against the live gateway config. Pure over its two inputs so it is unit-testable without disk.