pub fn attention_efficiency(
line_importances: &[f64],
alpha: f64,
beta: f64,
gamma: f64,
) -> f64Expand description
Compute the theoretical attention efficiency for a given context layout. Returns a percentage [0, 100] indicating how much of the context is in attention-optimal positions.