flush_sources

Function flush_sources 

pub fn flush_sources()
Persist the in-process counters by adding them into the cumulative on-disk file, then reset the process counters. The counters live in the MCP/CLI process — the dashboard is a separate process and can only see them through this file (#505).