pub fn memory_usage(cache: &SharedBm25Cache) -> usizeExpand description
Returns the approximate heap memory used by the cached BM25 index, or 0.
pub fn memory_usage(cache: &SharedBm25Cache) -> usizeReturns the approximate heap memory used by the cached BM25 index, or 0.