pub fn check_alert() -> Option<(CacheAlertSeverity, String)>Expand description
Generate a cache alert if hit rate is below thresholds.
pub fn check_alert() -> Option<(CacheAlertSeverity, String)>Generate a cache alert if hit rate is below thresholds.