cognitive_per_function

Function cognitive_per_function 

pub fn cognitive_per_function(
    source: &str,
    extension: &str,
) -> Option<Vec<FunctionCognitive>>
Compute cognitive complexity per function for source of the given file extension. Returns None when tree-sitter is disabled, the extension is unsupported, or the file has no functions.