analyze_file

Function analyze_file 

pub fn analyze_file(source: &str, extension: &str) -> Option<FileHealth>
Analyze one file’s source for the given file extension.

Returns None only when tree-sitter is disabled or the extension is unsupported (i.e. no functions could be parsed). Naming findings default to empty when the language has no analyzable identifiers.