evaluate

Function evaluate 

pub fn evaluate(old: &str, new: &str, ext: &str) -> GateOutcome
Evaluate the gate for an edit from oldnew source in a file with ext, using the active [code_health] config (threshold + mode).