pub fn load(root: &str) -> Option<PersistedHealth>Expand description
Load the persisted health for root, or None when absent/unreadable.
pub fn load(root: &str) -> Option<PersistedHealth>Load the persisted health for root, or None when absent/unreadable.