insert

Function insert 

pub fn insert(path: &Path, state: FileState, content: Arc<str>)
Insert (or replace) the content for path at version state. Skipped while the process is under memory pressure or when the cache is disabled, so the cache never adds to a memory problem.