pub struct ContextIrSafetyV1 {
pub redacted: bool,
pub boundary_mode: Option<String>,
}Fields
redacted: boolTrue if redaction has been applied to any stored text fields.
boundary_mode: Option<String>Human hint for the boundary mode at the time of collection, if known.