pub fn message_id(message: &MessageEntry) -> StringExpand description
Compute the stable content ID used to track whether a message was read.
pub fn message_id(message: &MessageEntry) -> StringCompute the stable content ID used to track whether a message was read.