pub fn should_supplement(config: &ActivationConfig) -> boolExpand description
Returns whether kernel supplementation should run in the configured mode.
pub fn should_supplement(config: &ActivationConfig) -> boolReturns whether kernel supplementation should run in the configured mode.