pub fn compute_delta(
base: &ContextCapsuleV1,
updated: &ContextCapsuleV1,
) -> DeltaTransferExpand description
Computes the reference and budget difference between two capsules.
pub fn compute_delta(
base: &ContextCapsuleV1,
updated: &ContextCapsuleV1,
) -> DeltaTransferComputes the reference and budget difference between two capsules.