pub fn dedup_siblings(capsules: &[ContextCapsuleV1]) -> DedupReportExpand description
Finds references shared across sibling capsules and reports transfer savings.
pub fn dedup_siblings(capsules: &[ContextCapsuleV1]) -> DedupReportFinds references shared across sibling capsules and reports transfer savings.