pub fn effective_config() -> (KernelFeatures, ConfigSource)Expand description
Returns the effective kernel features and their detected source.
pub fn effective_config() -> (KernelFeatures, ConfigSource)Returns the effective kernel features and their detected source.