pub struct ContentFingerprint {
pub hash: String,
pub token_estimate: usize,
pub delivered_at: Instant,
}Expand description
Tracks the identity of content that was delivered to the LLM.
Fields
hash: StringBlake3 content hash, truncated to 16 hexadecimal characters.
token_estimate: usizeApproximate number of tokens in the delivered content.
delivered_at: InstantTime at which this version of the content was delivered.