pub fn detect_coverage(
has_proxy: bool,
has_mcp: bool,
has_hooks: bool,
) -> CoverageClassExpand description
Detects the strongest coverage class supported by the available integrations.
pub fn detect_coverage(
has_proxy: bool,
has_mcp: bool,
has_hooks: bool,
) -> CoverageClassDetects the strongest coverage class supported by the available integrations.