pub enum DedupAction {
DeliverFull,
DeliverStub {
stub: String,
},
DeliverModified,
}Expand description
Action to take based on a content deduplication check.
Variants
DeliverFull
Content is new and should be delivered in full.
DeliverStub
Content is unchanged and can be replaced by a compact reference.
DeliverModified
Content changed and should be delivered in full.