pub fn check_content(path: &str, content: &str) -> DedupActionExpand description
Checks whether content changed since its last delivery at path.
pub fn check_content(path: &str, content: &str) -> DedupActionChecks whether content changed since its last delivery at path.