Module enforce

Module enforce 

Kernel policy enforcement modes.

Structs

BlockedEntry
A selected plan entry rejected by policy.
EnforceResult
Result of applying a policy to a context plan.

Enums

KernelMode
Determines whether policy violations are observed or enforced.

Functions

enforce_plan
Applies policy decisions according to the requested kernel mode.
resolve_mode
Resolves the kernel mode from the environment, then the global config.