pub fn resolve_mode(_project_root: &str) -> KernelModeExpand description
Resolves the kernel mode from the environment, then the global config.
pub fn resolve_mode(_project_root: &str) -> KernelModeResolves the kernel mode from the environment, then the global config.