Module health

Module health 

Aggregated Context Kernel health reporting.

Structs

HealthReport
Snapshot of health and activity across Context Kernel subsystems.

Functions

format_health
Formats a one-line human-readable Context Kernel health summary.
is_healthy
Returns whether the initialized Context Kernel is enabled and error-free.
kernel_health
Returns an aggregated snapshot of Context Kernel health and activity.
subsystem_names
Returns the names of subsystems represented by HealthReport.