Module kernel_config

Module kernel_config 

Central runtime configuration for Context Kernel features.

Structs

KernelFeatures
Runtime feature toggles for the Context Kernel.

Functions

features
Returns a snapshot of the current kernel feature configuration.
from_env
Builds kernel feature configuration from supported environment variables.
is_enabled
Returns whether Context Kernel processing is enabled.
is_feature_enabled
Returns whether a named feature and the master kernel switch are enabled.
reset_features
Restores the runtime feature configuration to its defaults.
update_features
Replaces the current kernel feature configuration.