Module learning

Module learning 

Receipt-driven learning for Context Kernel provider weights.

Structs

OutcomeLearner
Converts receipt outcomes into bounded provider weight updates.
WeightUpdate
A provider weight change inferred from a receipt outcome.

Functions

learn_and_update
Learns provider changes from a receipt and persists the receipt feedback.