pub fn identity_summary() -> IdentityLedgerSummaryExpand description
Returns aggregate identity attribution recorded by the proxy bridge.
pub fn identity_summary() -> IdentityLedgerSummaryReturns aggregate identity attribution recorded by the proxy bridge.