pub struct StreamController { /* private fields */ }Expand description
Tracks append streams and computes minimal synchronization deltas.
Implementations
Sourceimpl StreamController
impl StreamController
Sourcepub fn new(max_tracked: usize, expiry_secs: u64) -> Self
pub fn new(max_tracked: usize, expiry_secs: u64) -> Self
Creates a controller with bounded tracking and expiry in seconds.
Sourcepub fn compute_delta(
&mut self,
stream_ref: &StreamRef,
current_content: &[String],
) -> StreamDelta
pub fn compute_delta( &mut self, stream_ref: &StreamRef, current_content: &[String], ) -> StreamDelta
Compares current content with tracked state and returns its minimal delta.
Sourcepub fn tracked_count(&self) -> usize
pub fn tracked_count(&self) -> usize
Returns the number of actively tracked streams.