pub fn compress_schema(schema: &ToolSchema) -> ToolSchemaExpand description
Returns a compact copy of a tool schema and recalculates its token estimate.
pub fn compress_schema(schema: &ToolSchema) -> ToolSchemaReturns a compact copy of a tool schema and recalculates its token estimate.