pub fn build(opts: &SnapshotOptions) -> Result<ContextSnapshotV1, String>Expand description
Build an in-memory snapshot from the current store state, finalizing its id
(and signing it when opts.sign). Does not persist anything.
pub fn build(opts: &SnapshotOptions) -> Result<ContextSnapshotV1, String>Build an in-memory snapshot from the current store state, finalizing its id
(and signing it when opts.sign). Does not persist anything.