pub fn create(opts: &SnapshotOptions) -> Result<ContextSnapshotV1, String>Expand description
Build, persist, and append the snapshot to the project’s timeline.
pub fn create(opts: &SnapshotOptions) -> Result<ContextSnapshotV1, String>Build, persist, and append the snapshot to the project’s timeline.