shared_engine_result

Function shared_engine_result 

pub fn shared_engine_result() -> Result<&'static EmbeddingEngine>
Global singleton embedding engine with the load error preserved for callers that can surface diagnostics to users.