Module evidence_classification

Module evidence_classification 

Deterministic classification of savings evidence.

Functions

classify
Classify the measurement method and evidence strength for a savings event.
confidence_for_class
Return the default confidence associated with an evidence class.