pub fn classify(
mechanism: &str,
has_tokenizer_count: bool,
is_holdout: bool,
) -> (MeasurementMethod, EvidenceClass)Expand description
Classify the measurement method and evidence strength for a savings event.
pub fn classify(
mechanism: &str,
has_tokenizer_count: bool,
is_holdout: bool,
) -> (MeasurementMethod, EvidenceClass)Classify the measurement method and evidence strength for a savings event.