ingest

Function ingest 

pub fn ingest(server: &str, _tool: &str, text: &str, project_root: &str)
Parse text for graph edges and merge them into the project’s property graph as cross-source edges. No-op on unparseable input or an empty edge set.