pub struct ReflectionInsight {
pub kind: EntryKind,
pub content: String,
pub confidence: f32,
}Expand description
A distilled, reusable insight derived from the gotcha trace.
Fields
kind: EntryKindcontent: Stringconfidence: f32Trait Implementations
Sourceimpl Clone for ReflectionInsight
impl Clone for ReflectionInsight
Sourcefn clone(&self) -> ReflectionInsight
fn clone(&self) -> ReflectionInsight
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReflectionInsight
impl Debug for ReflectionInsight
Sourceimpl PartialEq for ReflectionInsight
impl PartialEq for ReflectionInsight
Sourcefn eq(&self, other: &ReflectionInsight) -> bool
fn eq(&self, other: &ReflectionInsight) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReflectionInsight