Module home

Module home 

Structs

CodexConfigPaths

Constants

CODEX_PROFILE_ENV
Compatibility with launchers that export the Codex profile name.
LEAN_CTX_CODEX_PROFILE_ENV
Explicit profile override understood by lean-ctx when it is run outside the Codex process that received --profile.

Functions

resolve_codex_config_path
Resolve the path lean-ctx should write for the active Codex profile.
resolve_codex_config_paths
Resolve both layers of the effective Codex configuration.
resolve_codex_dir
Resolve the Codex config directory. Respects CODEX_HOME env var (official Codex CLI feature). Falls back to ~/.codex when unset or empty.
resolve_home_dir
Resolve the user’s home directory in a way that is: