sample_array

Function sample_array 

pub fn sample_array(value: &Value, opts: &SampleOpts) -> Option<SampleResult>
Sample a JSON array, returning the representative subset with a summary. Returns None if the array is too small or not an array of objects.