Functions
- init_
logging - Initialize the tracing subscriber for CLI usage.
- init_
mcp_ logging - Initialize logging for daemon/MCP mode (stderr, defaults to
info). Daemon logs go to a file, so verbosity is fine.
info).
Daemon logs go to a file, so verbosity is fine.