pub fn init_mcp_logging()Expand description
Initialize logging for daemon/MCP mode (stderr, defaults to info).
Daemon logs go to a file, so verbosity is fine.
pub fn init_mcp_logging()Initialize logging for daemon/MCP mode (stderr, defaults to info).
Daemon logs go to a file, so verbosity is fine.