pub fn current_pressure() -> PressureLevelExpand description
Returns the current pressure level as last observed by the guardian thread.
pub fn current_pressure() -> PressureLevelReturns the current pressure level as last observed by the guardian thread.