pub fn jemalloc_purge()Expand description
Force-purge all jemalloc arenas to return memory to the OS.
Uses MALLCTL_ARENAS_ALL (value 4096) which is the jemalloc sentinel
for “all arenas”. Logs errors instead of silently swallowing them.
pub fn jemalloc_purge()Force-purge all jemalloc arenas to return memory to the OS.
Uses MALLCTL_ARENAS_ALL (value 4096) which is the jemalloc sentinel
for “all arenas”. Logs errors instead of silently swallowing them.