pub struct PersistedCacheEntry {
pub entry: DeliveryEntryV2,
pub persisted_at_epoch_ms: u64,
}Expand description
Serializable manifest record for an entry retained in the disk cache.
Fields
entry: DeliveryEntryV2The delivery entry represented by this manifest record.
persisted_at_epoch_ms: u64Time at which the entry was persisted, in Unix epoch milliseconds.