pub struct CapsuleStore { /* private fields */ }Implementations
Sourceimpl CapsuleStore
impl CapsuleStore
pub fn new() -> Self
pub fn register(&self, data: &[u8]) -> String
pub fn fork(&self, parent_ref: &str, budget_tokens: u64) -> OclaResult<String>
pub fn resolve(&self, capsule_ref: &str) -> OclaResult<Vec<u8>>
pub fn apply_delta(&self, capsule_ref: &str, delta: Delta) -> OclaResult<()>
pub fn merge_back(&self, child_ref: &str) -> OclaResult<()>
Sourcepub fn snapshot(&self, capsule_ref: &str) -> OclaResult<CapsuleSnapshot>
pub fn snapshot(&self, capsule_ref: &str) -> OclaResult<CapsuleSnapshot>
Creates a snapshot of the current capsule state for potential rollback.
Sourcepub fn rollback(&self, capsule_ref: &str, snapshot_id: &str) -> OclaResult<()>
pub fn rollback(&self, capsule_ref: &str, snapshot_id: &str) -> OclaResult<()>
Rolls back a capsule to a previous snapshot.
Sourcepub fn compute_handoff_delta(
&self,
from_ref: &str,
to_ref: &str,
) -> OclaResult<HandoffDelta>
pub fn compute_handoff_delta( &self, from_ref: &str, to_ref: &str, ) -> OclaResult<HandoffDelta>
Computes a compressed delta between two capsule versions.
Sourcepub fn apply_handoff_delta(
&self,
base_ref: &str,
delta: &HandoffDelta,
) -> OclaResult<String>
pub fn apply_handoff_delta( &self, base_ref: &str, delta: &HandoffDelta, ) -> OclaResult<String>
Applies a handoff delta to create a new capsule version.
pub fn stats(&self) -> CapsuleStats