Module compose_cache

Module compose_cache 

Section-aware cache for ctx_compose results.

Structs

ComposeSectionCache
In-process composition cache. A record is valid only when every source file still has the digest used to build its ComposedContextKey.

Functions

global