pub struct ComposeSectionCache { /* private fields */ }Expand description
In-process composition cache. A record is valid only when every source file
still has the digest used to build its ComposedContextKey.
Implementations