pub fn load_bundle(path: &Path) -> Result<PolicyBundle, String>Expand description
Loads a JSON policy bundle and rejects a bundle with a mismatched content hash.
pub fn load_bundle(path: &Path) -> Result<PolicyBundle, String>Loads a JSON policy bundle and rejects a bundle with a mismatched content hash.