pub fn analyze(response: &str, sources: &[String]) -> EchoReportExpand description
Pure analysis: which share of the response’s code lines appear verbatim in any source document (recently read file contents)?
pub fn analyze(response: &str, sources: &[String]) -> EchoReportPure analysis: which share of the response’s code lines appear verbatim in any source document (recently read file contents)?