Module argocd

Module argocd 

Argo CD (argocd app get/sync/list) output compression.

argocd app get/sync print a key/value metadata header followed by a resource table where most rows are Synced/Healthy (noise). We keep the important status keys (sync/health/phase/message/url) and only the resource rows that are not both Synced and Healthy, plus a kept/total tally.

Functions

compress