pub struct BuildPhases {
pub compile_phase: String,
pub diagnostic_phase: String,
pub result_phase: String,
}Expand description
Separates Cargo output into its progress, diagnostic, and result sections.
Fields
compile_phase: StringLeading Compiling, Checking, and Downloading progress lines.
diagnostic_phase: StringLines after progress and before Cargo reports a final result.
result_phase: StringLines beginning with Finished or test result:.