Module semgrep

Module semgrep 

Semgrep output compression.

Semgrep’s text output wraps findings in a banner, scan-progress lines and a code preview (gutter lines containing ). We drop that noise and keep the findings (rule id, file, message) plus the final Ran N rules ... findings summary.

Functions

compress