pub fn is_layer_enabled(kind: LayerKind, cfg: &PipelineConfig) -> boolExpand description
Returns whether a given layer is enabled according to a profile’s pipeline config.
pub fn is_layer_enabled(kind: LayerKind, cfg: &PipelineConfig) -> boolReturns whether a given layer is enabled according to a profile’s pipeline config.