pub fn active() -> Option<Arc<ActivePolicy>>Expand description
The active resolved policy, or None when no (valid) project pack exists.
Loaded once and cached; call reload after the pack changes.
pub fn active() -> Option<Arc<ActivePolicy>>The active resolved policy, or None when no (valid) project pack exists.
Loaded once and cached; call reload after the pack changes.