pub struct PrefetchModel { /* private fields */ }Expand description
Tracks prediction accuracy for model self-evaluation.
Implementations
Sourceimpl PrefetchModel
impl PrefetchModel
pub fn new() -> Self
Sourcepub fn predict(
&self,
current_hash: u64,
active_hashes: &[u64],
) -> Vec<(u64, f64)>
pub fn predict( &self, current_hash: u64, active_hashes: &[u64], ) -> Vec<(u64, f64)>
Predict which files will be accessed next, based on current state. Returns (path_hash, confidence) pairs sorted by confidence descending.
Sourcepub fn report_hit(&mut self, predicted_hash: u64, was_accessed: bool)
pub fn report_hit(&mut self, predicted_hash: u64, was_accessed: bool)
Report whether a predicted file was actually accessed (feedback loop).
Sourcepub fn free_energy(&self) -> f64
pub fn free_energy(&self) -> f64
Free Energy = surprise metric. High value means predictions are poor.
Sourcepub fn should_prefetch(&self) -> bool
pub fn should_prefetch(&self) -> bool
Should we actively prefetch? Only when model has learned enough and prediction accuracy is reasonable.