append_savings

Function append_savings 

pub fn append_savings(
    output: &str,
    original: usize,
    compressed: usize,
) -> String
Appends a savings footer to output with a newline separator, but only if the footer is non-empty.