pub struct ProviderCacheState { /* private fields */ }Expand description
Tracks which sections have been sent to the provider.
Implementations
Sourceimpl ProviderCacheState
impl ProviderCacheState
pub fn new() -> Self
Sourcepub fn needs_update(&self, section: &CacheableSection) -> bool
pub fn needs_update(&self, section: &CacheableSection) -> bool
Check if a section has changed since last sent.
Sourcepub fn mark_sent(&mut self, section: &CacheableSection)
pub fn mark_sent(&mut self, section: &CacheableSection)
Mark a section as sent to the provider.
Sourcepub fn filter_changed<'a>(
&mut self,
sections: &'a [CacheableSection],
) -> Vec<&'a CacheableSection>
pub fn filter_changed<'a>( &mut self, sections: &'a [CacheableSection], ) -> Vec<&'a CacheableSection>
Filter sections to only include those that changed. Stable sections that haven’t changed can be skipped (provider caches them).
pub fn cache_hit_rate(&self) -> f64
pub fn reset(&mut self)