pub fn compression_text(level: CompressionLevel) -> &'static strExpand description
Return the compression prompt text for a given level (empty string for Off).
pub fn compression_text(level: CompressionLevel) -> &'static strReturn the compression prompt text for a given level (empty string for Off).