pub fn list_rules(project_root: &str) -> Vec<RuleSummary>Expand description
List the generated rules currently on disk for the configured scope.
pub fn list_rules(project_root: &str) -> Vec<RuleSummary>List the generated rules currently on disk for the configured scope.