pub enum QualitySignal {
Bounce,
EditFail,
CleanCompressed,
WastedFull,
}Variants
Bounce
Compressed read was followed by a full re-read within the bounce window.
EditFail
An edit failed after the file was last read in a compressed mode.
CleanCompressed
A compressed read that (so far) was not bounced.
WastedFull
A large full read of an extension that never bounces — compression would almost certainly have been safe.