pub struct TokenCalibrationReportV1 {
pub schema_version: String,
pub report_version: String,
pub provider: String,
pub model: String,
pub tokenizer_family: String,
pub authority_ref: Option<String>,
pub entries: Vec<TokenCalibrationEntry>,
pub corpus_digest: String,
}Expand description
Versioned provider-count calibration report.
Fields
schema_version: Stringreport_version: Stringprovider: Stringmodel: Stringtokenizer_family: StringImmutable authority/evidence reference. None is never consumable.
entries: Vec<TokenCalibrationEntry>Sorted, unique provider observations.
corpus_digest: Stringblake3: digest over the canonical report payload excluding this field.
Implementations
Sourceimpl TokenCalibrationReportV1
impl TokenCalibrationReportV1
Constructs an authoritative report and computes its deterministic digest.
Sourcepub fn validate(&self) -> Result<(), TokenCalibrationError>
pub fn validate(&self) -> Result<(), TokenCalibrationError>
Validates all bounds, canonical ordering, authority, and digest fields.
Sourcepub fn canonical_json(&self) -> Result<Vec<u8>, TokenCalibrationError>
pub fn canonical_json(&self) -> Result<Vec<u8>, TokenCalibrationError>
Returns canonical JSON only for a fully validated report.