pub fn run(dir: &Path, opts: &InitOptions) -> Result<InitOutcome>Expand description
Runs the init: creates the directory and all files. See module docs.
Errors
Fails if any target file already exists, on CSPRNG failure, or on I/O.
pub fn run(dir: &Path, opts: &InitOptions) -> Result<InitOutcome>Runs the init: creates the directory and all files. See module docs.
Fails if any target file already exists, on CSPRNG failure, or on I/O.