pub struct MeUsageResponse {
pub person: String,
pub team: Option<String>,
pub org_label: Option<String>,
pub version: String,
pub from: String,
pub to: String,
pub totals: MeTotals,
pub by_model: Vec<MeModelRow>,
pub by_project: Vec<MeProjectRow>,
pub days: Vec<TimeseriesPoint>,
}Expand description
Response of GET /api/me/usage.
Fields
person: StringThe person this data belongs to (pseudonymized when GDPR mode is on — the same form the store holds, so what you see is what is stored).
team: Option<String>org_label: Option<String>version: Stringfrom: Stringto: Stringtotals: MeTotalsby_model: Vec<MeModelRow>by_project: Vec<MeProjectRow>days: Vec<TimeseriesPoint>Trait Implementations
Sourceimpl Clone for MeUsageResponse
impl Clone for MeUsageResponse
Sourcefn clone(&self) -> MeUsageResponse
fn clone(&self) -> MeUsageResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MeUsageResponse
impl Debug for MeUsageResponse
Sourceimpl<'de> Deserialize<'de> for MeUsageResponse
impl<'de> Deserialize<'de> for MeUsageResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for MeUsageResponse
impl PartialEq for MeUsageResponse
Sourcefn eq(&self, other: &MeUsageResponse) -> bool
fn eq(&self, other: &MeUsageResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MeUsageResponse
impl Serialize for MeUsageResponse
impl StructuralPartialEq for MeUsageResponse