pub struct HybridJsonRpcMessageCodec<T> { /* private fields */ }Trait Implementations
Sourceimpl<T: Clone> Clone for HybridJsonRpcMessageCodec<T>
impl<T: Clone> Clone for HybridJsonRpcMessageCodec<T>
Sourcefn clone(&self) -> HybridJsonRpcMessageCodec<T>
fn clone(&self) -> HybridJsonRpcMessageCodec<T>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug> Debug for HybridJsonRpcMessageCodec<T>
impl<T: Debug> Debug for HybridJsonRpcMessageCodec<T>
Sourceimpl<T: DeserializeOwned> Decoder for HybridJsonRpcMessageCodec<T>
impl<T: DeserializeOwned> Decoder for HybridJsonRpcMessageCodec<T>
Sourcetype Error = HybridCodecError
type Error = HybridCodecError
The type of unrecoverable frame decoding errors. Read more
Sourcefn decode(&mut self, buf: &mut BytesMut) -> Result<Option<T>, HybridCodecError>
fn decode(&mut self, buf: &mut BytesMut) -> Result<Option<T>, HybridCodecError>
Attempts to decode a frame from the provided buffer of bytes. Read more
Sourcefn decode_eof(
&mut self,
buf: &mut BytesMut,
) -> Result<Option<T>, HybridCodecError>
fn decode_eof( &mut self, buf: &mut BytesMut, ) -> Result<Option<T>, HybridCodecError>
A default method available to be called when there are no more bytes
available to be read from the underlying I/O. Read more