pub async fn handler(__arg0: Json<CompressRequest>) -> impl IntoResponseExpand description
Axum handler. Malformed bodies are rejected by the Json extractor (400).
pub async fn handler(__arg0: Json<CompressRequest>) -> impl IntoResponseAxum handler. Malformed bodies are rejected by the Json extractor (400).