Session-scoped cache for deduplicating compressed tool results.
Structs
- Dedup
Hit - A prior tool result that can be represented by a compact stub.
- Tool
Result Cache - Thread-safe cache of compressed tool results for one proxy session.