pub struct ToolResultCache { /* private fields */ }Expand description
Thread-safe cache of compressed tool results for one proxy session.
Implementations
Sourceimpl ToolResultCache
impl ToolResultCache
pub fn new() -> Self
Sourcepub fn check(&self, tool_name: &str, content: &str) -> Option<DedupHit>
pub fn check(&self, tool_name: &str, content: &str) -> Option<DedupHit>
Check whether this exact content was already compressed in this session.
Sourcepub fn insert(
&self,
tool_name: &str,
content: &str,
token_count: usize,
ccr_handle: Option<String>,
)
pub fn insert( &self, tool_name: &str, content: &str, token_count: usize, ccr_handle: Option<String>, )
Insert a tool result after compression.
Sourcepub fn advance_turn(&self)
pub fn advance_turn(&self)
Advance the session’s API-request turn counter.