pub fn snapshot(active: Option<Effort>) -> EffortStatsExpand description
Snapshot the counters together with the currently resolved effort level
(None → "off").
pub fn snapshot(active: Option<Effort>) -> EffortStatsSnapshot the counters together with the currently resolved effort level
(None → "off").