classify_turn

Function classify_turn 

pub fn classify_turn(messages: &Value) -> TurnClass
Classify the current turn based on the message array. Returns Routine if the latest context is a simple tool-result acknowledgement, Full otherwise.