pub struct SessionOptimizer {
pub cache: ResponseCache,
pub dedup: DedupTracker,
pub config: ResponseOptimizerConfig,
pub stats: OptimizerStats,
}Expand description
Per-session optimizer state. Each session/conversation gets its own instance.
Fields
cache: ResponseCachededup: DedupTrackerconfig: ResponseOptimizerConfigstats: OptimizerStatsImplementations
Sourceimpl SessionOptimizer
impl SessionOptimizer
pub fn new(config: ResponseOptimizerConfig) -> Self
Sourcepub fn try_cache_hit(&mut self, cache_key: u64) -> Option<&str>
pub fn try_cache_hit(&mut self, cache_key: u64) -> Option<&str>
Check if a request can be served from cache. Returns the cached response body if available.
Sourcepub fn record_response(
&mut self,
cache_key: u64,
response: &str,
output_tokens: u64,
) -> OptimizationDecision
pub fn record_response( &mut self, cache_key: u64, response: &str, output_tokens: u64, ) -> OptimizationDecision
Record a response for future cache lookups and dedup detection.
Sourcepub fn cache_hit_decision(
&self,
cache_key: u64,
tokens_saved: u64,
) -> OptimizationDecision
pub fn cache_hit_decision( &self, cache_key: u64, tokens_saved: u64, ) -> OptimizationDecision
Build a decision record for a cache hit.