Module compaction_sync

Module compaction_sync 

Statics

LAST_COMPACTION_TS

Functions

effective_cache_policy
Effective cache policy: “aggressive” (default), “safe”, or “off”.
sync_if_compacted
Check if a host compaction event occurred since our last check. If so, reset all full_content_delivered flags so the next read delivers full content instead of a stub.