sync_if_compacted

Function sync_if_compacted 

pub fn sync_if_compacted(cache: &mut SessionCache, data_dir: &Path) -> bool
Check if a host compaction event occurred since our last check. If so, reset all full_content_delivered flags so the next read delivers full content instead of a stub.