pub fn check_tool_access(tool_name: &str) -> PolicyCheckResultExpand description
Check whether tool_name is allowed by the active policy pack, recording an
audit entry on denial (same APIs as super::role_guard).
pub fn check_tool_access(tool_name: &str) -> PolicyCheckResultCheck whether tool_name is allowed by the active policy pack, recording an
audit entry on denial (same APIs as super::role_guard).