pub struct ToolOutput {
pub text: String,
pub original_tokens: usize,
pub saved_tokens: usize,
pub mode: Option<String>,
pub path: Option<String>,
pub changed: bool,
pub shell_outcome: Option<ShellOutcome>,
pub content_blocks: Option<Vec<ContentBlock>>,
}Expand description
Result returned by an McpTool handler.
Fields
text: Stringoriginal_tokens: usizesaved_tokens: usizemode: Option<String>path: Option<String>Path associated with the tool call (for record_call_with_path).
changed: boolTrue when the tool mutated state that clients should know about (e.g. dynamic tool categories changed).
shell_outcome: Option<ShellOutcome>Set by shell-executing tools so dispatch can populate isError +
structuredContent on the MCP result (GitHub #389). None for tools
that don’t run shell commands.
content_blocks: Option<Vec<ContentBlock>>Override content blocks for non-text responses (e.g. images).
When set, dispatch uses these instead of wrapping text in TextContent.
Implementations
Sourceimpl ToolOutput
impl ToolOutput
pub fn simple(text: String) -> Self
Sourcepub fn to_header_line(&self, tool_name: &str) -> String
pub fn to_header_line(&self, tool_name: &str) -> String
Compact one-line summary for headers_only response verbosity.
pub fn with_savings(text: String, original: usize, saved: usize) -> Self
Sourcepub fn image(blocks: Vec<ContentBlock>, path: String) -> Self
pub fn image(blocks: Vec<ContentBlock>, path: String) -> Self
Construct a ToolOutput for image/binary content blocks. Bypasses all text processing in the dispatch pipeline.