pub fn handle(cache: &mut SessionCache, params: &PatchParams) -> StringExpand description
Apply an anchored patch and the resulting cache effect in one shot (tests and in-process callers that hold the cache exclusively).
pub fn handle(cache: &mut SessionCache, params: &PatchParams) -> StringApply an anchored patch and the resulting cache effect in one shot (tests and in-process callers that hold the cache exclusively).