Module ctx_plan

Module ctx_plan 

ctx_plan – Context planning tool.

Given a task and budget, computes the optimal context plan using the Context Field potential function, intent router, and deficit analysis.

Functions

handle
plan_to_candidates
Convert the plan into compile candidates for use with the compiler.