Module search_kernel

Module search_kernel 

Evidence and repeated-query tracking for the search tool.

Structs

SearchSummary
Cumulative search activity for the current session.

Functions

is_repeated_query
Returns whether the query has already been recorded in this session.
record_search
Records search evidence and remembers the query for repetition detection.
reset
Clears all recorded search activity.
search_summary
Returns cumulative search activity for the current session.