Re-exports
pub use dispatch::run;
Modules
Structs
Constants
Functions
- cmd_
benchmark - cmd_
cache - cmd_
cheatsheet - cmd_
compression - cmd_
config - cmd_
deps - cmd_
diff - cmd_
discover - cmd_
filter - cmd_
find - cmd_
ghost - cmd_
grep - cmd_
init - cmd_
init_ quiet - cmd_
ledger - cmd_ls
- cmd_
profile - cmd_
read - cmd_
session_ action - cmd_
sessions - cmd_
slow_ log - cmd_
stats - cmd_tee
- cmd_
theme - cmd_
wrapped - generate_
hook_ fish - generate_
hook_ posix - generate_
hook_ powershell - init_
fish - init_
posix - init_
powershell - load_
shell_ history_ pub - print_
hook_ stdout - prune_
bm25_ caches - prune_
graph_ caches - remove_
lean_ ctx_ block - remove_
lean_ ctx_ block_ ps - show_
first_ run_ wow - Shows the discover “you’re leaving X tokens on the table” moment exactly once, right
after setup. Marker-guarded so re-running
setupnever repeats it. Stays silent (but still marks done) when there is too little history to be meaningful, so it never nags. Reads only local shell history and prints aggregate estimates — never command contents. - write_
env_ sh_ for_ containers