U-shaped placement (primacy/recency): alternate placing ranked items at context head vs tail.
Functions
- reorder_
for_ attention - Sort by descending importance, then assign alternating fronts (
front) vs backs (back).
U-shaped placement (primacy/recency): alternate placing ranked items at context head vs tail.
front) vs backs (back).