Content deduplication for context delivered to language models.
Structs
- Content
Fingerprint - Tracks the identity of content that was delivered to the LLM.
- Context
Dedup - Bounded content deduplication tracker. Remembers what was sent to the LLM to avoid resending unchanged content.
Enums
- Dedup
Result - Whether content needs to be sent or was already delivered.
Functions
- dedup_
kernel_ blocks - Replaces repeated Context Kernel blocks with compact reference stubs.
- estimate_
tokens - Estimates token usage using an average of four UTF-8 bytes per token.
- format_
unchanged_ stub - Formats a compact reference to unchanged content already in context.