Kernel policy enforcement modes.
Structs
- Blocked
Entry - A selected plan entry rejected by policy.
- Enforce
Result - Result of applying a policy to a context plan.
Enums
- Kernel
Mode - Determines whether policy violations are observed or enforced.
Functions
- enforce_
plan - Applies policy decisions according to the requested kernel mode.
- resolve_
mode - Resolves the kernel mode from the environment, then the global config.