Central runtime configuration for Context Kernel features.
Structs
- Kernel
Features - Runtime feature toggles for the Context Kernel.
Functions
- features
- Returns a snapshot of the current kernel feature configuration.
- from_
env - Builds kernel feature configuration from supported environment variables.
- is_
enabled - Returns whether Context Kernel processing is enabled.
- is_
feature_ enabled - Returns whether a named feature and the master kernel switch are enabled.
- reset_
features - Restores the runtime feature configuration to its defaults.
- update_
features - Replaces the current kernel feature configuration.