Evidence chain for context delivery lifecycles.
Structs
- Chain
Entry - A single entry in the receipt chain — one context delivery lifecycle.
- Chain
Summary - Aggregate statistics for the receipt chain.
Functions
- accepted_
entries - Returns an owned snapshot containing only accepted entries.
- chain_
entries - Returns an owned snapshot of the full chain.
- chain_
length - Returns the number of entries in the chain.
- chain_
summary - Returns aggregate statistics for all recorded entries.
- kernel_
hit_ rate - Returns the fraction of entries supplemented by the kernel.
- record_
chain_ entry - Records a context delivery lifecycle and returns its monotonic chain ID.
- rejected_
entries - Returns an owned snapshot containing only rejected entries.
- reset_
chain - Clears all entries and resets the monotonic counter for testing.