pub fn shared_engine_result() -> Result<&'static EmbeddingEngine>Expand description
Global singleton embedding engine with the load error preserved for callers that can surface diagnostics to users.
pub fn shared_engine_result() -> Result<&'static EmbeddingEngine>Global singleton embedding engine with the load error preserved for callers that can surface diagnostics to users.