Modules
- chunking
- Theta-gamma chunking for wakeup facts (#543, EFF-6).
- maintenance
- Maintenance for the on-disk knowledge stores.
Structs
- Consolidated
Insight - Contradiction
- Fidelity
Score - Import
Result - Judged
Pair - Knowledge
Fact - Project
Knowledge - Project
Pattern - Similar
Fact - Simple
Fact Entry - Community-compatible simple fact format for import/export interop.
Enums
- Admission
Result - Outcome of a write-time admission decision (#970), returned by
ProjectKnowledge::remember_admitted. It is the difference between “the agent asked to store X” and “what lean-ctx actually persisted”. - Contradiction
Severity - Import
Merge - Knowledge
Archetype
Constants
- COGNITION_
SYNTHESIS_ SOURCE source_sessionmarker for facts written by the cognition loop’s observation synthesis step (#802). Lets recall distinguish synthesized entity-summaries from user-supplied findings (both areObservationarchetype).- COMPACTION_
DIGEST_ SOURCE source_sessionmarker for digest facts written by the cognition loop’s cluster-compaction step (#971). A digest replaces a cluster of low-value, mutually-similar facts; the originals are archived (recoverable). Excluded from being compacted again so digests never cannibalize each other.
Functions
- find_
cross_ key_ similar - parse_
import_ data - Parse import data: tries native
ProjectKnowledgefirst, then simple[{...}]array.