pub fn cluster_facts<'a>(facts: &[&'a KnowledgeFact]) -> Vec<FactCluster<'a>>Expand description
Greedy agglomerative chunking. Input order is the salience order — the first member of each cluster is its most salient fact, and clusters are returned in the order of their founding (= salience) fact.