Structs
Functions
- detect_
project_ root - detect_
project_ root_ or_ cwd - encode_
instructions - Encode an instruction suffix using short codes with budget hints. Response budget is dynamic based on task complexity to shape LLM output length.
- encode_
instructions_ with_ snr - Encode instructions with SNR metric for context quality awareness.
- format_
savings - instruction_
decoder_ block - Build the decoder block that explains all instruction codes (sent once per session).
- shorten_
path