Graph builder for repo map.
Constructs a file-level directed graph from the project index edges and call graph edges, then exposes symbol definitions per file.
Graph builder for repo map.
Constructs a file-level directed graph from the project index edges and call graph edges, then exposes symbol definitions per file.