pub fn animate_section_reveal(sections: &[String], delay_ms: u64)
Writes sections to stdout one by one with a delay between each, using cursor control to create a reveal effect. Skips animation when NO_COLOR or non-TTY.
NO_COLOR