Module daemon_client

Module daemon_client 

Functions

daemon_health_check
Check if the daemon is reachable by hitting /health.
daemon_request
Send an HTTP request to the daemon over the Unix Domain Socket. Returns the response body as a string.
daemon_tool_call
Call a tool on the daemon’s REST API.
try_daemon_request
Attempt to connect to the daemon. Returns None if not running.
try_daemon_tool_call_blocking
Blocking helper for CLI commands: calls a daemon tool if the daemon is running. Returns None if the daemon is not running or the call fails. On Unix, attempts to auto-start the daemon if it’s not already running.
try_daemon_tool_call_blocking_text
Like try_daemon_tool_call_blocking, but unwraps MCP JSON responses to text for CLI output.