Module daemon_client
lean_
ctx
3.5.4
Module daemon_
client
Module Items
Functions
In crate lean_
ctx
lean_ctx
Module
daemon_
client
Functions

daemon_
health_
check
Check if the daemon is reachable by hitting /health.
daemon_
request
Send an HTTP request to the daemon over the Unix Domain Socket. Returns the response body as a string.
daemon_
tool_
call
Call a tool on the daemon’s REST API.
try_
daemon_
request
Attempt to connect to the daemon. Returns
None
if not running.
try_
daemon_
tool_
call_
blocking
Blocking helper for CLI commands: calls a daemon tool if the daemon is running. Returns
None
if the daemon is not running or the call fails. On Unix, attempts to auto-start the daemon if it’s not already running.
try_
daemon_
tool_
call_
blocking_
text
Like
try_daemon_tool_call_blocking
, but unwraps MCP JSON responses to text for CLI output.