pub fn try_daemon_tool_call_blocking(
name: &str,
arguments: Option<Value>,
) -> Option<String>Expand description
Blocking helper for CLI commands: calls a daemon tool if the daemon is running.
Returns None if the daemon is not running or the call fails.
On Unix, attempts to auto-start the daemon if it’s not already running.