Functions
- install_
agent_ hook - install_
project_ rules - refresh_
installed_ hooks - Silently refresh all hook scripts for agents that are already configured. Called after updates and on MCP server start to ensure hooks match the current binary version.
- to_
bash_ compatible_ path