Module hooks

Module hooks 

Functions

install_agent_hook
install_project_rules
refresh_installed_hooks
Silently refresh all hook scripts for agents that are already configured. Called after updates and on MCP server start to ensure hooks match the current binary version.
to_bash_compatible_path