Functions
- read
- Acquire a read lock with an adaptive timeout based on I/O health.
Returns
Noneon timeout (caller must provide graceful fallback). Records a freeze event for self-healing if the timeout is hit. - write
- Acquire a write lock with an adaptive timeout based on I/O health.
Returns
Noneon timeout (caller must provide graceful fallback). Records a freeze event for self-healing if the timeout is hit.