Statics
Functions
- effective_
cache_ policy - Effective cache policy: “aggressive” (default), “safe”, or “off”.
- sync_
if_ compacted - Check if a host compaction event occurred since our last check.
If so, reset all
full_content_deliveredflags so the next read delivers full content instead of a stub.