pub fn handle(cache: &mut SessionCache, params: &EditParams) -> StringExpand description
Performs a string replacement edit on a file with CRLF/LF and whitespace tolerance.
pub fn handle(cache: &mut SessionCache, params: &EditParams) -> StringPerforms a string replacement edit on a file with CRLF/LF and whitespace tolerance.