handle_file

Function handle_file 

pub fn handle_file(
    path: &str,
    intent: Option<&str>,
    project_root: Option<&str>,
) -> String
Reads a file from disk, detects its language, and executes a processing script.

project_root is used for pathjail validation. If None, the current directory is used as the jail root.