Evidence and repeated-query tracking for the search tool.
Structs
- Search
Summary - Cumulative search activity for the current session.
Functions
- is_
repeated_ query - Returns whether the query has already been recorded in this session.
- record_
search - Records search evidence and remembers the query for repetition detection.
- reset
- Clears all recorded search activity.
- search_
summary - Returns cumulative search activity for the current session.